.. image:: _static/bmi-tester-logo-text-lowercase.png
    :align: center
    :scale: 10%
    :alt: Sequence
    :target: https://sequence.readthedocs.org/


The `bmi_tester` package provides command-line utilities for testing
a Python classes that implement the Basic Model Interface (BMI).
`bmi_tester` also provides a Python interface to the tester that allows
users to run tests programmatically. The package is also easily
extendable so that new tests can be added to the suite.


Getting Started
---------------

.. toctree::
   :maxdepth: 3

   readme

..   usage
..   installation

API Reference
-------------

If you are looking for information on a specific function, class, or
method, this part of the documentation is for you.

.. toctree::
   :maxdepth: 2

   api/index


Miscellaneous Pages
-------------------

.. toctree::
   :maxdepth: 2

   authors
   changelog
   license


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
